==> terraform-0.2.10.tgz: terraform-0.2.10/src/GuiDialogYN.h <==
/* Terraform - (C) 1997-1998 Robert Gasch (Robert_Gasch@peoplesoft.com)
 *  - www.peoplesoft.com/peoplepages/g/robert_gasch/terraform/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */


#ifndef _GUI_DIALOG_YN_H
#define _GUI_DIALOG_YN_H


#include <gtk--.h>
#include <gtk/gtk.h>


/*
 *  GuiDialogYN: create a basic dialog dialog with 2 buttons 
 */
class GuiDialogYN : public Gtk_Dialog
	{
	public: 
					GuiDialogYN (char *winTitle=NULL, char *frameTitle=NULL);
					~GuiDialogYN (); 
		virtual void		buildDialogWindow ();

	protected: 	
		void			setupVBox ();
		virtual void 		fillVBox ();
		virtual void		fillActionArea ();
		virtual void 		buttonCallbackYes ();
		virtual void 		buttonCallbackNo ();
		virtual gint		delete_event_impl (GdkEventAny *e);


		Gtk_Button		d_buttonYes, 
					d_buttonNo; 
  		Gtk_Frame		*d_baseFrame;
		char			*d_winTitle,
					*d_frameTitle;
	};


#endif // _GUI_DIALOG_YN_H

==> terraform-0.2.11.tgz: terraform-0.2.11/src/GuiDialogYN.h <==
/* Terraform - (C) 1997-1998 Robert Gasch (Robert_Gasch@peoplesoft.com)
 *  - www.peoplesoft.com/peoplepages/g/robert_gasch/terraform/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */


#ifndef _GUI_DIALOG_YN_H
#define _GUI_DIALOG_YN_H


#include <gtk--.h>
#include <gtk/gtk.h>


/*
 *  GuiDialogYN: create a basic dialog dialog with 2 buttons 
 */
class GuiDialogYN : public Gtk_Dialog
	{
	public: 
					GuiDialogYN (char *winTitle=NULL, char *frameTitle=NULL);
					~GuiDialogYN (); 
		virtual void		buildDialogWindow ();

	protected: 	
		void			setupVBox ();
		virtual void 		fillVBox ();
		virtual void		fillActionArea ();
		virtual void 		buttonCallbackYes ();
		virtual void 		buttonCallbackNo ();
		virtual gint		delete_event_impl (GdkEventAny *e);


		Gtk_Button		d_btnYes, 
					d_btnNo; 
  		Gtk_Frame		*d_baseFrame;
		char			*d_winTitle,
					*d_frameTitle;
	};


#endif // _GUI_DIALOG_YN_H
